@@ -1,4 +1,4 @@
 from skyhookdmclient.skyhook import SkyhookDM
 import skyhookdmclient.skyhook_common
-from skyhookdmclient.skyhook import TableGroup
+from skyhookdmclient.skyhook import Database
 
