@@ -7,41 +7,33 @@ class SkyhookDM:
         self.client = None
         self.addr = None
 
-        # try:
-        #     self.cluster = rados.Rados(conffile='/etc/ceph/ceph.conf')
-        #     self.cluster.connect()
-
-        # except Exception as e:
-        #     print(str(e))
-
     def connect(self, ip, ceph_pool_name):
         addr = ip+':8786'
         self.addr = addr
         client = Client(addr)
         self.client = client
         self.ceph_pool = ceph_pool_name
-        # self.ioctx = self.cluster.open_ioctx(ceph_pool_name)
+
+    def saveDatabase(self, db):
+
+        def runOnDriver(buff_bytes, name,  ceph_pool):
+            from skyhookdmdriver import skyhook_driver as sd
+            res = sd.writeToCeph(buff_bytes, name, ceph_pool)
+            return res
+        
+        fu = self.client.submit(runOnDriver, db.serialize(), db.getName(), self.ceph_pool)
+        result = fu.result()
+        return result
 
 
     # Write the arrow table to Ceph
-    # Do we need to serialize it?
-    # Exception Handling
-    # Maintain Metadata
-    # Object namming
-    # Merge object?
-    # Split object?
-    # Submit to driver?
-    def writeArrowTable(self, table_group_name, table_name, table):
+    def write(self, table, db_name, prefix, table_name, type= 'arrow', partitioner = None, mode = 'create|overwrite'):
         
         def runOnDriver(buff_bytes, name,  ceph_pool):
             from skyhookdmdriver import skyhook_driver as sd
             res = sd.writeToCeph(buff_bytes, name, ceph_pool)
             return res
 
-        # In the servicex case, the data_schema_name is did for now
-        # the data_schema_name is not checked so far. Will add the logic later.
-        # May also need to get the object of data_schema_name and add new information about the tables written into the SkyhookDM
-
         id_array = range(len(table.columns[0]))
         event_id_col = pa.field('EVENT_ID', pa.int64())
 
@@ -63,8 +55,9 @@ class SkyhookDM:
             
             buff = sink.getvalue()
             buff_bytes = buff.to_pybytes()
+            buff_bytes = addFB_Meta(buff_bytes)
 
-            sub_table_name = table_group_name + '#' + table_name + '#' + table.column_names[i] + '.0.0'
+            sub_table_name = db_name + '#' + prefix + '#' + table_name + '#' + table.column_names[i] + '.0.0'
             fu = self.client.submit(runOnDriver, buff_bytes, sub_table_name, self.ceph_pool)
             result = fu.result()
             if result is True:
@@ -73,33 +66,6 @@ class SkyhookDM:
         return object_names
 
 
-    def addDatasetSchema(self, schema_json, data_type = 'servicex'):
-        def runOnDriver(schema_json, name, data_type, ceph_pool):
-            from skyhookdmdriver import skyhook_driver as sd
-            res = sd.addDatasetSchema(schema_json, name, data_type, ceph_pool)
-            return res
-
-        values = json.loads(schema_json)
-
-        # the name of the schema is named after the did for now
-        name = values['did']
-
-        fu = self.client.submit(runOnDriver, schema_json, name, data_type, self.ceph_pool)
-        result = fu.result()
-    
-    def createTableGroup(self, table_group):
-        
-        def runOnDriver(buff_bytes, name,  ceph_pool):
-            from skyhookdmdriver import skyhook_driver as sd
-            res = sd.writeToCeph(buff_bytes, name, ceph_pool)
-            return res
-        
-        fu = self.client.submit(runOnDriver, table_group.serialize(), table_group.getName(), self.ceph_pool)
-
-        result = fu.result()
-
-
-
     def writeDataset(self, path, dstname):
         def runOnDriver(path, dstname, poolname, addr ):
             # import skyhook_driver as sd
@@ -136,10 +102,8 @@ class SkyhookDM:
 
     def runQuery(self, obj, querystr):
         #limit just to 1 obj
-        # command_template = '--wthreads 1 --qdepth 120 --query hep --pool hepdatapool --start-obj #startobj --output-format \"SFT_PYARROW_BINARY\" --data-schema \"#dataschema\" --project \"#colname\" --num-objs #objnum --oid-prefix \"#prefix\" --table-name \"#tablename\" --subpartitions 10'
         command_template = ['--wthreads', '1',  '--qdepth', '120',  '--query', 'hep', '--pool', self.ceph_pool, '--output-format', 'SFT_PYARROW_BINARY', '--num-objs', '1', '--subpartitions', '10']
 
-
         def generateQueryCommand(file, querystr):
             cmds = []
             prefix = file.dataset + '#' + str(file.name) + '#' + str(file.ROOTDirectory)
@@ -157,8 +121,6 @@ class SkyhookDM:
                 obj_prefix = prefix + local_prefix + '#'
                 data_schema = ''
 
-                # print(obj_prefix)
-
                 f_schema = file.getSchema()
                 found = False
 
@@ -248,8 +210,8 @@ class SkyhookDM:
                 while True:
                     if cursor == stream_length:
                         break
-                    sizebf = tablestream[cursor:cursor+4]
-                    cursor = cursor + 4
+                    sizebf = tablestream[cursor:cursor+8]
+                    cursor = cursor + 8
                     size = struct.unpack("<i",sizebf)[0]
                     stream = tablestream[cursor:cursor+size]
                     cursor = cursor + size
@@ -305,8 +267,8 @@ class SkyhookDM:
                     while True:
                         if cursor == stream_length:
                             break
-                        sizebf = tablestream[cursor:cursor+4]
-                        cursor = cursor + 4
+                        sizebf = tablestream[cursor:cursor+8]
+                        cursor = cursor + 8
                         size = struct.unpack("<i",sizebf)[0]
                         stream = tablestream[cursor:cursor+size]
                         cursor = cursor + size
@@ -333,7 +295,6 @@ class SkyhookDM:
         return None
 
 
-
 class LazyDataframe:
 
     def __init__(self, arr_table, entrysteps = -1):
@@ -372,29 +333,20 @@ class LazyDataframe:
         self._batches = self._arr_table.to_batches(entrysteps)
 
 
-
-# CREATE TABLE Persons (
-#     PersonID int,
-#     LastName varchar(255),
-#     FirstName varchar(255),
-#     Address varchar(255),
-#     City varchar(255)
-# );
-
-class TableGroup:
-    def __init__(self, table_group_name, metadata = None):
-        self._name = table_group_name
+class Database:
+    def __init__(self, db_name, metadata = None):
+        self._name = db_name
         self.schema = {}
-        self.schema['table_group_name'] = table_group_name
+        self.schema['db_name'] = db_name
         self.schema['metadata'] = metadata
-        self.schema['type'] = 'servicex'
         self.tables = []
     
 
-    def addTable(self, table_name, arrow_schema, metadata = None):
-        schema = arrow_schema
+    def createTable(self, prefix, table_name, table_schema, tag = '', metadata = None):
+        schema = table_schema
 
         table = {}
+        table['prefix'] = prefix
         table['table_name'] = table_name
 
         col_list = []
@@ -417,5 +369,4 @@ class TableGroup:
         return buff_bytes
 
     def getName(self):
-        return self._name
-
+        return self._name
\ No newline at end of file
